🔖 [Table of Contents](../README.md)

# FAQ

- [Why Python](why-python.md)
- [Does Zrb have a scheduler](does-zrb-have-a-scheduler.md)
- [How to get data from other tasks](how-to-get-data-from-other-tasks.md)

🔖 [Table of Contents](../README.md)
